@@ -1,8 +1,8 @@
 from .worker import ValiotWorker
-from .worker import QueueType, JobStatus, PollingMode, JobConfigMode
+from .worker import QueueType, JobStatus, PollingMode, JobConfigMode, QueryOrderBy
 from .uploaders import update_job
 
 # * Package name:
 name = 'ValiotWorker'
 # * required here for pypi upload exceptions:
-__version__ = "4.1.0"
+__version__ = "4.2.1"
