@@ -49,6 +49,13 @@ class PollingMode(Enum):
     SUBSCRIPTION = 'SUBSCRIPTION'
 
 
+class QueryOrderBy(Enum):
+    """Set Query Filert OrderBy
+    """
+    ID = 'ID'
+    INSERTED_AT = 'INSERTED_AT'
+
+
 class JobConfigMode(Enum):
     """Enumeration for all the job's configurations
     """
@@ -156,6 +163,7 @@ class ValiotWorker():
         self.worker = None
         self.worker_code = None
         self.pollingMode = PollingMode.QUERY
+        self.queryOrderBy = QueryOrderBy.ID
         self.jobConfigMode = JobConfigMode.KEEP
         self.context = None
         self.unsubJobCreated = None
@@ -195,6 +203,14 @@ class ValiotWorker():
         """
         self.pollingMode = mode
 
+    def setQueryOrderBy(self, orderBy):
+        """Sets QueryOrderBy option
+
+        Args:
+            orderBy (QueryOrderBy): QueryOrderBy option.
+        """
+        self.queryOrderBy = orderBy
+
     def setJobConfigMode(self, mode):
         """Sets Jobs configuration.
 
@@ -673,8 +689,10 @@ class ValiotWorker():
     def processJobs(self):
         """This function manages the process of a Job.
         """
+        orderBy = self.queryOrderBy.value
         jobs, errors = self.gql.query(queries.all_jobs, variables={
-                                      'worker': self.worker['code']})
+                                      'worker': self.worker['code'],
+                                      'orderByJob': {'asc': orderBy}})
         if errors:
             message = errors[0]
             self.log(LogLevel.ERROR, f'Error! msg: {message}')
@@ -744,11 +762,13 @@ class ValiotWorker():
             schedule = __.get(queue, 'schedule', None)
             query = __.get(queue, 'query', None)
             lockRequired = __.get(queue, 'lockRequired', False)
+            enabled = __.get(queue, 'enabled', None)
             variables = {
                 'name': queue['name'],
                 'alias': queue['alias'],
                 'type': queue['type'],
-                'lockRequired': lockRequired
+                'lockRequired': lockRequired,
+                'enabled': enabled if isinstance(enabled, bool) else None
             }
             # ! Add optional variables
             if description:
@@ -1119,8 +1139,11 @@ class ValiotWorker():
             queue_name = __.get(shedeuleQueue, 'name', None)
             if queue_name:
                 self.continuousJobs.append(queue_name)
+                orderBy = self.queryOrderBy.value
                 queueLocks, errors = self.gql.query(queries.get_queueLocks, variables={
-                    "workerCode": self.worker_code, "queueName": queue_name})
+                    "workerCode": self.worker_code,
+                    "queueName": queue_name,
+                    'orderByQueueLock': {'desc': orderBy}})
                 if errors:
                     self.log(LogLevel.ERROR,
                              f'Error get_queueLocks:\n{errors}')
@@ -1237,8 +1260,12 @@ class ValiotWorker():
             interval (float, optional): Interval time of each loop. Defaults to 1.0.
         """
         try:
+            orderBy = self.queryOrderBy.value
             currentQueues, errors = self.gql.query(
-                queries.all_queues_w_listeners)
+                queries.all_queues_w_listeners,
+                variables={
+                    'orderByJob': {'desc': orderBy},
+                    'orderByQueueLock': {'desc': orderBy}})
             if (errors):
                 self.log(LogLevel.ERROR, f'errors: {errors}')
                 return
@@ -1265,10 +1292,10 @@ class ValiotWorker():
     def getWorker(self):
         """This function gets the worker information.
         """
+        orderBy = self.queryOrderBy.value
         worker, errors = self.gql.query_one(
             queries.get_worker,
-            {'code': self.worker_code}
-        )
+            {'code': self.worker_code, 'orderByJob': {'desc': orderBy}})
         if errors:
             log(LogLevel.ERROR, errors)
             raise Exception('Worker not found')
